@@ -113,37 +113,25 @@ fn new_lines_ignored() {
         vec![
             ChangeText::new(
                 &Text::new("0"),
-                PatchPath::new(
-                    TreePath::start_at(8, vec![0, 1, 0, 0, 0, 0, 0,]),
-                    TreePath::start_at(14, vec![0, 1, 0, 0, 0, 0, 0,])
-                ),
+                TreePath::start_at(8, vec![0, 1, 0, 0, 0, 0, 0,]),
                 &Text::new("1")
             )
             .into(),
             ChangeText::new(
                 &Text::new("2"),
-                PatchPath::new(
-                    TreePath::start_at(26, vec![0, 1, 0, 0, 2, 0, 0,]),
-                    TreePath::start_at(32, vec![0, 1, 0, 0, 2, 0, 0,])
-                ),
+                TreePath::start_at(26, vec![0, 1, 0, 0, 2, 0, 0,]),
                 &Text::new("3")
             )
             .into(),
             ChangeText::new(
                 &Text::new("3"),
-                PatchPath::new(
-                    TreePath::start_at(38, vec![0, 1, 0, 0, 3, 0, 0,]),
-                    TreePath::start_at(44, vec![0, 1, 0, 0, 3, 0, 0,])
-                ),
+                TreePath::start_at(38, vec![0, 1, 0, 0, 3, 0, 0,]),
                 &Text::new("4")
             )
             .into(),
             InsertNode::new(
                 Some(&"div"),
-                PatchPath::new(
-                    TreePath::start_at(6, vec![0, 1, 0, 0, 0,]),
-                    TreePath::start_at(6, vec![0, 1, 0, 0, 0,])
-                ),
+                TreePath::start_at(6, vec![0, 1, 0, 0, 0,]),
                 &div(
                     vec![class("grid__number__line")],
                     vec![
@@ -158,10 +146,7 @@ fn new_lines_ignored() {
             .into(),
             InsertNode::new(
                 Some(&"div"),
-                PatchPath::new(
-                    TreePath::start_at(24, vec![0, 1, 0, 0, 2,]),
-                    TreePath::start_at(24, vec![0, 1, 0, 0, 2,])
-                ),
+                TreePath::start_at(24, vec![0, 1, 0, 0, 2,]),
                 &div(
                     vec![class("grid__number__line")],
                     vec![
@@ -176,15 +161,12 @@ fn new_lines_ignored() {
             .into(),
             RemoveNode::new(
                 Some(&"div"),
-                PatchPath::old(TreePath::start_at(18, vec![0, 1, 0, 0, 1,]),),
+                TreePath::start_at(18, vec![0, 1, 0, 0, 1,]),
             )
             .into(),
             ChangeText::new(
                 &Text::new("line: 0, column: 0"),
-                PatchPath::new(
-                    TreePath::start_at(49, vec![0, 1, 0, 1, 0,]),
-                    TreePath::start_at(55, vec![0, 1, 0, 1, 0,])
-                ),
+                TreePath::start_at(49, vec![0, 1, 0, 1, 0,]),
                 &Text::new("line: 1, column: 0")
             )
             .into(),
